#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Tests for `healthyhouse_api` package."""

import pytest

#from click.testing import CliRunner

from healthyhouse_api import healthyhouse_api
#from healthyhouse_api import cli

def test_nothing():
    assert 1 == 1
# @pytest.fixture
# def response():
#     """Sample pytest fixture.

#     See more at: http://doc.pytest.org/en/latest/fixture.html
#     """
#     # import requests
#     # return requests.get('https://github.com/audreyr/cookiecutter-pypackage')


#def test_content(response):
#    """Sample pytest test function with the pytest fixture as an argument."""
#    # from bs4 import BeautifulSoup
#    # assert 'GitHub' in BeautifulSoup(response.content).title.string


# def test_command_line_interface():
#     """Test the CLI."""
#     runner = CliRunner()
#     result = runner.invoke(cli.main)
#     assert result.exit_code == 0
#     assert 'healthyhouse_api.cli.main' in result.output
#     help_result = runner.invoke(cli.main, ['--help'])
#     assert help_result.exit_code == 0
#     assert '--help  Show this message and exit.' in help_result.output



# -*- coding: utf-8 -*-

"""
Realization of the RESTAPI for healthyhouse
"""
import requests

class Healthyhouse(object):
    '''
    This class implements the healthyhouse web restful api
    '''

    def __init__(self, token, server):
        self.rm_auth_headers = \
            {'Authorization': 'Token {}'.format(token)}
        self.server = server

    def set_results(self, results):
        """
        results dict should have structure like this:
        [
            {
               "id": 12120,
               "concentration": 45,
               "uncertainty": 23
            },
            {
               "id": 11495,
               "concentration": 78,
               "uncertainty": 6
            }
        ]
        """
        return requests.post(
                '{}/api/v1/dosimeters/set-results/'.format(self.server),
                headers = self.rm_auth_headers,
                json = results
        )

    def get_report(self, order_number):
        '''
        Retrieves a report.
        To access encoded content, look in response.text
        To access binary content (which could e.g. get dumped directly to a file) look in response.content
        '''
        return requests.get(
                '{}/api/v1/orders/generate_reports_pdf/?order_number={}'.format(self.server, order_number),
                headers = self.rm_auth_headers
        )

    def get_invoice(self, order_number):
        '''
        Retrieves an invoice.
        To access encoded content, look in response.text
        To access binary content (which could e.g. get dumped directly to a file) look in response.content
        '''
        return requests.get(
                '{server}/api/v1/orders/generate_invoices_pdf/?order_number={order_number}'.format(server = self.server, order_number = order_number),
                headers = self.rm_auth_headers
        )

    def import_order(
            self,
            country=None,          # String 'dk'
            currency=None,         # String 'DKK'
            date_placed=None,      # String (Y-%m-%d %H:%M)
            email=None,            # String
            first_name=None,       # String
            last_name=None,        # String
            line1=None,            # 'address'
            partner_code=None,     # 'partner_0001'
            partner_name=None,     # 'Bolius'
            partner_order_id=None, # '12345'
            phone_number=None,     # '+45123456' Remember country code
            postcode=None,         # '1234'
            product=None,          # 'integer, eg. 1' What is this?
            quantity=None,         # Integer
            serial_numbers=None,   # List of strings
            shipping_code=None,    # String
            shipping_excl_tax=None,# integer
            shipping_id=None,      # String
            shipping_incl_tax=None,# float
            shipping_method=None,  # What to use here?
            state=None,            # String
            status=None,           # String e.g. created or issued
            total_excl_tax=None,   # float
            total_incl_tax=None    # float
        ):
        '''
        Inserts an order into radonmeters system
        '''
        body = {k:v for k, v in locals().items() if v is not None and v is not self}
        return requests.post(
            '{}/api/v1/data-import/orders/'.format(self.server),
            headers=self.rm_auth_headers,
            data=body
        )



# -*- coding: utf-8 -*-

"""Console script for healthyhouse_api."""

import argparse
from marshmallow import Schema, fields, validates, ValidationError, pre_load
import os
import healthyhouse_api as hh_api
import pandas as pd

class Inputvalidation(Schema):
    '''
    Example usage of validator with filename validation excluded:
    data, errors = Job(exclude=('filename',)).load({'infile':'./somefile.csv','server':'https://xyz.com', 'token': '1234'})
    '''
    infile = fields.String( required = True)
    server = fields.String( required = True)
    token = fields.String( required = True)
    
    @validates('infile')
    def validate_filename(self, value):
        if not os.path.isfile(value):
            raise ValidationError('Supplied filename {} does not point to a fileresource'.format(value))
    

def main():

    desc = """
Import orders from csv file.
csv file should have the following structure:

country,currency,date_placed,email,first_name,last_name,address,city,phone_number,zipcode,partner_order_id,serialno
dk,DKK,2018-01-31 00:00,foobar@gmail.com,John,Doe,"Noway 4, st. mf.",København,"+4522345129",1874,12734;12730;12724
dk,DKK,2018-02-31 00:00,info@aasdert.com,Jan,Karlsen,"wayway 4,",Silkeborg,"+4512345678",8700,12744;12745;12746;12747
dk,DKK,2018-01-01 00:00,asdf@gmail.com,fname,name2,"hayway 4,",Horsens,"+4512345678",8700,22744;22745;22746
"""
    parser = argparse.ArgumentParser(description=desc)
    parser.add_argument('-i', '--infile',
                        help='csv file containing lab results to be ingested',
                        default="")
    parser.add_argument('-s', '--server',
                        help='URL for running instance of healthyhouse.',
                        default = None)
    parser.add_argument('-t', '--token',
                        help='Token for using the webservices',
                        default = None)
    
    
    data = Inputvalidation().load(vars(parser.parse_args()))
    
    HH = hh_api.Healthyhouse(data['token'], server=data['server'])
    df = pd.read_csv(data['infile'])
    #dct = df.to_dict(orient='records')
    #print('Inserting {count} rows...'.format(count=len(df)))
    #res = HH.set_results(
    #    [{k: int(v) for k, v in d.items()} for d in dct]
    #)
    # if res.status_code != 200:
    #     print('Error code: {}'.format(res.status_code) )
    #     print(res.text)
    # else:
    #     print('Done')
    return 0

if __name__ == "__main__":
    import sys
    sys.exit(main())
